################### PROGRAMA DE CALCULO DEL INDICE DE REZAGO SOCIAL 2010 ###################

#Este programa de calculo utiliza la base de datos del ITER 2010 en formato *.dbf 
#esta base puede ser obtenida en la pagina de Internet del INEGI https://www.inegi.org.mx/

#En este programa se utilizan dos tipos de archivos: base original y bases generadas
#El primero es el directorio donde se encuentra la base del ITER 2010 (ITER_NALDBF10.dbf) 
#En el segundo se guardan las bases de datos generadas por el programa
#1) Base original:   "C:/isr/base"
#2) Bases generadas: "C:/isr/temp"

#Se instalan los paquetes necesarios para este programa de calculo
install.packages("foreign", dependencies = T)
install.packages("dplyr", dependencies = T)

library(foreign)
library(dplyr)

rm(list=ls())
setwd("C:/Retrospect/isr")

base <-read.dbf("base/ITER_NALDBF10.dbf", as.is = TRUE)
names(base) <-tolower(names(base))

base$clave_mun <-paste0(base$entidad, base$mun, sep = "") %>% as.character()
base$clave_loc <-paste0(base$entidad, base$mun, base$loc, sep = "") %>% as.character()

base2 <-data.frame(lapply(base, as.numeric))
base_nom <-data.frame(base$nom_ent,base$nom_mun, base$nom_loc) 
base2 <-data.frame(base_nom, base2)

base3 <-dplyr::filter(base2, !(is.na(pobmas) | is.na(p_0a2)))
base3$comparativo <-base3$vph_pisodt + base3$vph_pisoti

base3$comp1 <-base3$comparativo / base3$vivpar_hab
base3$comp2 <-base3$comparativo / base3$tvivparhab

summary(dplyr::select(base3, comp1, comp2))

base3$i_analf    <-base3$p15ym_an / base3$p_15ymas 
base3$i_asistesc <-(base3$p6a11_noa+ base3$p12a14noa) / ( base3$p_6a11+ base3$p_12a14)
base3$i_edbasinc <-(base3$p15ym_se + base3$p15pri_in + base3$p15pri_co + base3$p15sec_in) / base3$p_15ymas
base3$i_sdsalud  <-base3$psinder / base3$pobtot
base3$i_ptierra  <-base3$vph_pisoti / base3$vivpar_hab
base3$i_hacin    <-base3$pro_ocup_c
base3$i_nosan    <-1-( base3$vph_excsa / base3$vivpar_hab)
base3$i_noagua   <- base3$vph_aguafv / base3$vivpar_hab
base3$i_nodren   <-base3$vph_nodren / base3$vivpar_hab
base3$i_noelec   <-base3$vph_s_elec / base3$vivpar_hab
base3$i_nolav    <-1-( base3$vph_lavad / base3$vivpar_hab)
base3$i_noref    <-1-(base3$vph_refri / base3$vivpar_hab)

base4 <-dplyr::select(base3, entidad ,base.nom_ent ,mun ,base.nom_mun ,loc ,base.nom_loc ,pobtot ,p_15ymas ,p_6a11 ,p_12a14 ,p6a11_noa ,p12a14noa ,p15ym_an ,
                      p15ym_se ,p15pri_in ,p15pri_co ,p15sec_in ,psinder ,vivpar_hab ,vph_pisoti ,pro_ocup_c ,vph_s_elec ,vph_aguafv ,
                      vph_excsa ,vph_nodren ,vph_refri ,vph_lavad ,clave_mun ,clave_loc ,i_analf ,i_asistesc ,i_edbasinc ,i_sdsalud ,i_ptierra ,
                      i_hacin ,i_nosan ,i_noagua ,i_nodren ,i_noelec ,i_nolav ,i_noref)

write.csv(base4, "temp/iter10_rezago.csv", row.names = F)

rm(list=ls())
###########################################Base Entidades########################################################

base_ent <-read.csv("temp/iter10_rezago.csv")

base_ent <-dplyr::filter(base_ent, base.nom_loc=="Total de la Entidad")

base_ent <-dplyr::select(base_ent, -mun, -base.nom_mun, -loc, 
                         -base.nom_loc, -clave_mun, -clave_loc)

write.csv(base_ent, "temp/rezago ent.csv", row.names = F)


###########################################Base Municipios#######################################################

base_mun <-read.csv("temp/iter10_rezago.csv")

base_mun <-dplyr::filter(base_mun, base.nom_loc=="Total del Municipio")

base_mun <-dplyr::select(base_mun, -loc, -base.nom_loc, -clave_loc)

write.csv(base_mun, "temp/rezago mun.csv", row.names = F)

##########################################Base Localidades#######################################################

base_loc <-read.csv("temp/iter10_rezago.csv")

base_loc <-dplyr::filter(base_loc, !(base.nom_loc=="Total de la Entidad" | base.nom_loc=="Localidades de una vivienda" | 
                                       base.nom_loc=="Localidades de dos viviendas" | base.nom_loc=="Total del Municipio" | base.nom_loc=="Total nacional"))

base_loc <-dplyr::filter(base_loc, vivpar_hab!=0)
base_loc$i_asistesc[base_loc$p_6a11==0 | base_loc$p_12a14==0] <-0
base_loc <-dplyr::filter(base_loc, p_15ymas!=0)

write.csv(base_loc, "temp/rezago loc_A.csv", row.names = F)

################### Analisis de Componentes Principales a nivel Localidad###################

cp.loc <-prcomp(dplyr::select(base_loc, i_analf, i_asistesc, i_edbasinc, i_sdsalud, i_ptierra,
                              i_nosan, i_noagua, i_nodren, i_noelec,  i_nolav, i_noref ), scale.=T )
print(cp.loc)
summary(cp.loc)

pred <-predict(cp.loc, newdata = base_loc)
pred <-as.data.frame(pred)
base_loc$indice <- pred$PC1

base_loc$indicenorm <-(base_loc$indice -mean(base_loc$indice))/sd(base_loc$indice)
base_loc$y <-100/(max(base_loc$indicenorm)-min(base_loc$indicenorm))*(base_loc$indicenorm-min(base_loc$indicenorm))

base_loc$intervalo[base_loc$y<=10] <-1
base_loc$intervalo[base_loc$y>10 & base_loc$y<=20] <-2
base_loc$intervalo[base_loc$y>20 & base_loc$y<=30] <-3
base_loc$intervalo[base_loc$y>30 & base_loc$y<=40] <-4
base_loc$intervalo[base_loc$y>40 & base_loc$y<=50] <-5
base_loc$intervalo[base_loc$y>50 & base_loc$y<=60] <-6
base_loc$intervalo[base_loc$y>60 & base_loc$y<=70] <-7
base_loc$intervalo[base_loc$y>70 & base_loc$y<=80] <-8
base_loc$intervalo[base_loc$y>80 & base_loc$y<=90] <-9
base_loc$intervalo[base_loc$y>90 & base_loc$y<=100] <-10

table(base_loc$intervalo)
base_loc <-arrange(base_loc, y)

base_loc$gdo_rez[base_loc$intervalo<=2] <-"Muy bajo"
base_loc$gdo_rez[base_loc$intervalo==3] <-"Bajo"
base_loc$gdo_rez[base_loc$intervalo>=4 & base_loc$intervalo<=5] <-"Medio"
base_loc$gdo_rez[base_loc$intervalo>5 & base_loc$intervalo<=7] <-"Alto"
base_loc$gdo_rez[base_loc$intervalo>7] <-"Muy alto"

group_by(base_loc, gdo_rez) %>%
  summarise(Media=mean(indicenorm), Mínimo=min(indicenorm), Máximo=max(indicenorm))
table(base_loc$gdo_rez)

write.csv(base_loc, "temp/rezago loc_A.csv", row.names = F)


rm(list=ls())
################### Analisis de Componentes Principales a nivel Municipal###################
base_mun <-read.csv("temp/rezago mun.csv")

cp.mun <-prcomp(dplyr::select(base_mun, i_analf, i_asistesc, i_edbasinc, i_sdsalud, i_ptierra,
                              i_nosan, i_noagua, i_nodren, i_noelec,  i_nolav, i_noref ), scale.=T )
print(cp.mun)
summary(cp.mun)

pred <-predict(cp.mun, newdata = base_mun)
pred <-as.data.frame(pred)
base_mun$indice <- pred$PC1

base_mun$indicenorm <-(base_mun$indice -mean(base_mun$indice))/sd(base_mun$indice)
base_mun$y <-100/(max(base_mun$indicenorm)-min(base_mun$indicenorm))*(base_mun$indicenorm-min(base_mun$indicenorm))

base_mun$intervalo[base_mun$y<=10] <-1
base_mun$intervalo[base_mun$y>10 & base_mun$y<=20] <-2
base_mun$intervalo[base_mun$y>20 & base_mun$y<=30] <-3
base_mun$intervalo[base_mun$y>30 & base_mun$y<=40] <-4
base_mun$intervalo[base_mun$y>40 & base_mun$y<=50] <-5
base_mun$intervalo[base_mun$y>50 & base_mun$y<=60] <-6
base_mun$intervalo[base_mun$y>60 & base_mun$y<=70] <-7
base_mun$intervalo[base_mun$y>70 & base_mun$y<=80] <-8
base_mun$intervalo[base_mun$y>80 & base_mun$y<=90] <-9
base_mun$intervalo[base_mun$y>90 & base_mun$y<=100] <-10

table(base_mun$intervalo)

base_mun$gdo_rez[base_mun$intervalo<=2] <-"Muy bajo"
base_mun$gdo_rez[base_mun$intervalo==3] <-"Bajo"
base_mun$gdo_rez[base_mun$intervalo==4] <-"Medio"
base_mun$gdo_rez[base_mun$intervalo>4 & base_mun$intervalo<=6] <-"Alto"
base_mun$gdo_rez[base_mun$intervalo>6] <-"Muy alto"

group_by(base_mun, gdo_rez) %>%
  summarise(Media=mean(indicenorm), Minimo=min(indicenorm), Maximo=max(indicenorm))
table(base_mun$gdo_rez)

write.csv(base_mun, "temp/rezago mun.csv")

rm(list=ls())
################### Analisis de Componentes Principales a nivel Estatal###################
base_ent <-read.csv("temp/rezago ent.csv")

cp.ent <-prcomp(dplyr::select(base_ent, i_analf, i_asistesc, i_edbasinc, i_sdsalud, i_ptierra,
                              i_nosan, i_noagua, i_nodren, i_noelec,  i_nolav, i_noref ), scale.=T )
print(cp.ent)
summary(cp.ent)

pred <-predict(cp.ent, newdata = base_ent)
pred <-as.data.frame(pred)
base_ent$indice <- pred$PC1

base_ent$indicenorm <-(base_ent$indice -mean(base_ent$indice))/sd(base_ent$indice)
base_ent$y <-100/(max(base_ent$indicenorm)-min(base_ent$indicenorm))*(base_ent$indicenorm-min(base_ent$indicenorm))

base_ent$intervalo[base_ent$y<=10] <-1
base_ent$intervalo[base_ent$y>10 & base_ent$y<=20] <-2
base_ent$intervalo[base_ent$y>20 & base_ent$y<=30] <-3
base_ent$intervalo[base_ent$y>30 & base_ent$y<=40] <-4
base_ent$intervalo[base_ent$y>40 & base_ent$y<=50] <-5
base_ent$intervalo[base_ent$y>50 & base_ent$y<=60] <-6
base_ent$intervalo[base_ent$y>60 & base_ent$y<=70] <-7
base_ent$intervalo[base_ent$y>70 & base_ent$y<=80] <-8
base_ent$intervalo[base_ent$y>80 & base_ent$y<=90] <-9
base_ent$intervalo[base_ent$y>90 & base_ent$y<=100] <-10

table(base_ent$intervalo)

base_ent$gdo_rez[base_ent$intervalo<=2] <-"Muy bajo"
base_ent$gdo_rez[base_ent$intervalo==3] <-"Bajo"
base_ent$gdo_rez[base_ent$intervalo==4] <-"Medio"
base_ent$gdo_rez[base_ent$intervalo>4 & base_ent$intervalo<=7] <-"Alto"
base_ent$gdo_rez[base_ent$intervalo>7] <-"Muy alto"

group_by(base_ent, gdo_rez) %>%
  summarise(Media=mean(indicenorm), Minimo=min(indicenorm), Maximo=max(indicenorm))
table(base_ent$gdo_rez)

write.csv(base_ent, "temp/rezago ent.csv")

